@@ -68,6 +68,8 @@ void KDFTopLevel::closeEvent(QCloseEvent *event)
 /***************************************************************/
 int main(int argc, char **argv)
 {
+    //Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kdf");
